# OpenAI MCP Server

An MCP Server for the OpenAI API.

## 🛠️ Tool List

This is automatically generated from OpenAPI schema for the OpenAI API.

| Tool                     | Description                                                               |
| ------------------------ | ------------------------------------------------------------------------- |
| `create_chat_completion` | Creates a model response for the given chat conversation.                 |
| `upload_file`            | Upload a file that can be used across various OpenAI API endpoints.       |
| `list_files`             | Lists the files that have been uploaded to your OpenAI account.           |
| `retrieve_file`          | Retrieves information about a specific file.                              |
| `delete_file`            | Deletes a file.                                                           |
| `retrieve_file_content`  | Retrieves the content of the specified file.                              |
| `generate_image`         | Creates an image given a prompt.                                          |
| `create_image_edit`      | Creates an edited or extended image given an original image and a prompt. |
| `create_image_variation` | Creates a variation of a given image.                                     |
| `create_transcription`   | Transcribes audio into the input language.                                |
| `create_translation`     | Translates audio into English text.                                       |
| `create_speech`          | Generates audio from the input text.                                      |
